Struct DriverBindingProtocol
Source #[repr(C)]
pub struct DriverBindingProtocol {
pub supported: unsafe extern "efiapi" fn(this: *const Self, controller_handle: Handle, remaining_device_path: *const DevicePathProtocol) -> Status,
pub start: unsafe extern "efiapi" fn(this: *const Self, controller_handle: Handle, remaining_device_path: *const DevicePathProtocol) -> Status,
pub stop: unsafe extern "efiapi" fn(this: *const Self, controller_handle: Handle, number_of_children: usize, child_handle_buffer: *const Handle) -> Status,
pub version: u32,
pub image_handle: Handle,
pub driver_binding_handle: Handle,
}
image_handle: Handledriver_binding_handle: Handle
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.